@@ -14,7 +14,7 @@ def test_xlsx():
         docs = json.load(fin)
         doc = Document(**docs[0])
         formatter = AFPQualityFormatter()
-        options = AFPQualityParameters()
+        options = AFPQualityParameters(text=True)
         resp: Response = formatter.format(doc, options)
         assert resp.status_code == 200
         assert resp.media_type == "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
